#!/bin/zsh

#-------- setup
module purge
module load DEVELOP
module load gcc
module load openmpi/1.8.1

VERS_MAJ=2
VERS_MIN=9
VERS_BUG=2
VERS_DOT=${VERS_MAJ}.${VERS_MIN}.${VERS_BUG}
VERS_ULINE=${VERS_MAJ}_${VERS_MIN}_${VERS_BUG}

BUILD_PATH=/home/vrsw/VisIt/install/${VERS_DOT}/gcc44_ompi181_debug
INST_PATH=/home/vrsw/VisIt/${VERS_DOT}/gcc44_ompi181_debug

BUILD_PROCS=8
BUILD_MODE=Debug

ROOT_PATH=`pwd`
ARCH=linux-`uname -m`
HOSTNAME=`hostname`

#------- print info
echo 
echo "-------------------------------------------------------------------"
echo "Building VisIt ${VERS_DOT} ${BUILD_MODE} for ${ARCH} on ${HOSTNAME}"
echo "  build path  : ${BUILD_PATH}"
echo "  install path: ${INST_PATH}"
echo "  build with no. procs: ${BUILD_PROCS}"
echo "-------------------------------------------------------------------"
echo " Loaded modules:"
module list
echo 

#------- prepare directories
mkdir -p ${BUILD_PATH}
cd ${BUILD_PATH}
if [ $? -eq 0 ]; then
    echo "SUCCESS: build directory created (${BUILD_PATH})"
else
    echo "ERROR: cannot create build directory (${BUILD_PATH})"
    exit
fi

#------- get build script
wget http://portal.nersc.gov/svn/visit/trunk/releases/${VERS_DOT}/build_visit${VERS_ULINE}
chmod +x build_visit${VERS_ULINE}
if [ $? -eq 0 ]; then
    echo "SUCCESS: build script downloaded"
else
    echo "ERROR: cannot download build script"
    exit
fi

#------- patch build script
patch -p0 -E build_visit${VERS_ULINE} << 'EOF'
@@ -1644,12 +1644,12 @@
         BYPASS_QT_LICENSE="yes"
     fi
 
-    if [[ "$BYPASS_QT_LICENSE" == "no" && "$DOWNLOAD_ONLY" == "no" ]] ; then
-        qt_license_prompt
-        if [[ $? != 0 ]] ;then
-            error "Qt4 Open Source Edition License Declined. Bailing out."
-        fi
-    fi
+#    if [[ "$BYPASS_QT_LICENSE" == "no" && "$DOWNLOAD_ONLY" == "no" ]] ; then
+#        qt_license_prompt
+#        if [[ $? != 0 ]] ;then
+#            error "Qt4 Open Source Edition License Declined. Bailing out."
+#        fi
+#    fi
 fi
 
 #
EOF

#------- build 3rd party libraries
echo "building 3rd party libraries ... "
echo "     be patient or check ${BUILD_PATH}/1-build_3rdparty.log"
echo 
echo " ./build_visit${VERS_ULINE} \ "
echo "            --console --no-visit \ "
echo "            --build-mode ${BUILD_MODE} --makeflags \"-j ${BUILD_PROCS}\" \ "
echo "            --parallel --fortran \ "
echo "            --cmake --mesa --python --vtk --qt --szip --zlib --boost \ "
echo "            --hdf5 --silo --netcdf --xdmf \ "
echo "            --prefix ${INST_PATH} > ${BUILD_PATH}/1-build_3rdparty.log"
echo
./build_visit${VERS_ULINE} \
           --console --no-visit \
           --build-mode ${BUILD_MODE} --makeflags "-j ${BUILD_PROCS}" \
           --parallel --fortran \
           --cmake --mesa --python --vtk --qt --szip --zlib --boost \
           --hdf5 --silo --netcdf --xdmf \
           --prefix ${INST_PATH} > ${BUILD_PATH}/1-build_3rdparty.log 2>&1
if [ $? -eq 0 ]; then
    echo "SUCCESS: 3rd party libraries build"
else
    echo "ERROR: cannot build 3rd party libraries"
    exit
fi

#------- download VisIt
echo "downloading VisIt source ... "
wget http://portal.nersc.gov/svn/visit/trunk/releases/${VERS_DOT}/visit${VERS_DOT}.tar.gz
tar -xzf visit${VERS_DOT}.tar.gz
if [ $? -eq 0 ]; then
    echo "SUCCESS: VisIt source downloaded and extracted"
else
    echo "ERROR: cannot download and extract VisIt source"
    exit
fi
        
#------- configure VisIt
echo "configuring VisIt ... "
echo "     be patient or check ${BUILD_PATH}/2-conf_visit.log"
cp ${HOSTNAME}.cmake visit${VERS_DOT}/src/config-site/
cd visit${VERS_DOT}/src

export CMAKE_BIN=`find ../../visit/cmake -mindepth 1 -maxdepth 1 -type d | sort | head -1`
export CMAKE_BIN=`find ${CMAKE_BIN}      -mindepth 1 -maxdepth 1 -type d | sort | head -1`
${CMAKE_BIN}/bin/cmake \
     -DCMAKE_BUILD_TYPE:STRING=${BUILD_MODE} \
     -DVISIT_PARALLEL:BOOL=ON \
     -DVISIT_FORTRAN:BOOL=ON \
     . > ${BUILD_PATH}/2-conf_visit.log 2>&1
if [ $? -eq 0 ]; then
    echo "SUCCESS: VisIt configured and Makefile created"
else
    echo "ERROR: cannot configure VisIt and create Makefile"
    exit
fi

#------- compile VisIt
echo "compiling VisIt ... "
echo "     be patient or check ${BUILD_PATH}/3-compile_visit.log"
make -j ${BUILD_PROCS} > ${BUILD_PATH}/3-compile_visit.log 2>&1
if [ $? -eq 0 ]; then
    echo "SUCCESS: VisIt compiled"
else
    echo "ERROR: cannot compile VisIt"
    exit
fi

#------- package VisIt
echo "package VisIt ... "
echo "     be patient or check ${BUILD_PATH}/4-package_visit.log"
make package > ${BUILD_PATH}/4-package_visit.log 2>&1
if [ $? -eq 0 ]; then
    echo "SUCCESS: VisIt packaged"
else
    echo "ERROR: cannot package VisIt"
    exit
fi

#------- install VisIt
echo "install VisIt ... "
echo "     be patient or check ${BUILD_PATH}/5-install_visit.log"
./svn_bin/visit-install -c none ${VERS_DOT} ${ARCH} ${INST_PATH} > ${BUILD_PATH}/5-install_visit.log 2>&1
if [ $? -eq 0 ]; then
    echo "SUCCESS: VisIt installed"
else
    echo "ERROR: cannot install VisIt"
    exit
fi

